std

module
v0.0.0-...-b6b1d6e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2021 License: GPL-3.0

README

STD

This project contains a bunch of functionality I consider would've been nice to have been included in the Go standard library.

WORK IN PROGRESS

Strings

Contains functionality related to string manipulation.

package main

import (
    "fmt"
    "github.com/calini/std/strings"
)

func main() {
    str := strings.Before("abcd", "c")
    fmt.Printf("%s\n", str) // "ab" 
}

Directories

Path Synopsis
extra
structs
WIP

Jump to