collection

package
v0.0.0-...-b6b1d6e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2021 License: GPL-3.0 Imports: 0 Imported by: 0

Documentation

Overview

WIP

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Collection

type Collection interface {
	// ensures that this collection contains the specified element (optional operation)
	Add(e Element) bool
	// adds all of the elements in the specified collection to this collection (optional operation)
	AddAll(c Collection) bool
	// removes all of the elements from this collection (optional operation)
	Clear()
	// returns true if this collection contains the specified element
	Contains(e Element) bool
	// returns true if this collection contains all of the elements in the specified collection
	ContainsAll(c Collection) bool
	// returns true if this collection contains no elements
	IsEmpty() bool
	// returns an iterator over the elements contained in this collection
	Iterator() Iterator
	// removes a single instance of the specified element from this collection, if it is present (optional operation)
	Remove(e Element) bool
	// removes all of this collection's elements that are also contained in the specified collection (optional operation)
	RemoveAll(c Collection) bool
	// retains only the elements in this collection that are contained in the specified collection (optional operation)
	RetainAll(c Collection) bool
	// returns the number of elements in this collection
	Size() int
	// returns an array containing all of the elements in this collection
	ToArray() []Element
	// returns a string representation of this collection
	String() string
}

Derived from java.util.AbstractCollection

type Element

type Element interface{}

type Iterator

type Iterator interface{}

Directories

Path Synopsis

Jump to